Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSaadia Dhouib2023-01-25 17:28:17 +0000
committerSaadia Dhouib2023-01-25 17:28:17 +0000
commit5c32c1e0d44b48ef9700e4861825d21025f2ed21 (patch)
treee2b328da32b7decd6f8b1ddbe50c9b57ddc010e7
parent3b2590a500061d14bcf9a94e25e05b9f801d88c1 (diff)
downloadorg.eclipse.papyrus-manufacturing-5c32c1e0d44b48ef9700e4861825d21025f2ed21.tar.gz
org.eclipse.papyrus-manufacturing-5c32c1e0d44b48ef9700e4861825d21025f2ed21.tar.xz
org.eclipse.papyrus-manufacturing-5c32c1e0d44b48ef9700e4861825d21025f2ed21.zip
[Bug 581385] NodeId description should support pub sub protocols
Adding NameSapceIndex and Topic attribute to the NodeId stereotype. Refactoring of the code generator in order to take into account the different kinds of protocols. Change-Id: I79d6c1a0910487f506cb0dd65067cb8760cbc4af Signed-off-by: Saadia Dhouib <saadia.dhouib@cea.fr>
-rw-r--r--aas/plugins/codegen/org.eclipse.aas.basyx.codegen/src/org/eclipse/aas/basyx/codegen/generator/submodel/DEWorkspaceCreator.java122
-rw-r--r--aas/plugins/modeling/org.eclipse.aas.api/src/org/eclipse/aas/api/communications/ProtocolKind.java2
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.codegen.ui/src/org/eclipse/papyrus/aas/codegen/ui/handlers/GenerateAASCodeHelper.java4
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/META-INF/MANIFEST.MF2
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/plugin.xml1
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/pom.xml2
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.ecore19
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.genmodel5
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.notation261
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.uml17
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/icons/AAS_16x16.pngbin0 -> 628 bytes
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/AASPackage.java78
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/NodeId.java82
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/ProtocolKind.java25
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/AASPackageImpl.java39
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/NodeIdImpl.java158
-rw-r--r--aas/plugins/modeling/org.eclipse.papyrus.designer.languages.java.codegen/src/org/eclipse/papyrus/designer/languages/java/codegen/utils/JavaGenUtils.java2
17 files changed, 612 insertions, 207 deletions
diff --git a/aas/plugins/codegen/org.eclipse.aas.basyx.codegen/src/org/eclipse/aas/basyx/codegen/generator/submodel/DEWorkspaceCreator.java b/aas/plugins/codegen/org.eclipse.aas.basyx.codegen/src/org/eclipse/aas/basyx/codegen/generator/submodel/DEWorkspaceCreator.java
index 38c74174..746eca9f 100644
--- a/aas/plugins/codegen/org.eclipse.aas.basyx.codegen/src/org/eclipse/aas/basyx/codegen/generator/submodel/DEWorkspaceCreator.java
+++ b/aas/plugins/codegen/org.eclipse.aas.basyx.codegen/src/org/eclipse/aas/basyx/codegen/generator/submodel/DEWorkspaceCreator.java
@@ -10,6 +10,7 @@
*
* Contributors:
* DFKI - Tapanta Bhanja <tapanta.bhanja@dfki.de>
+ * CEA LIST - Saadia DHOUIB <saadia.dhouib@cea.fr>
*******************************************************************************/
package org.eclipse.aas.basyx.codegen.generator.submodel;
@@ -19,6 +20,8 @@ import java.util.Collection;
import java.util.LinkedList;
import java.util.List;
+import org.eclipse.aas.api.communications.Endpoint;
+import org.eclipse.aas.api.communications.ProtocolKind;
import org.eclipse.aas.api.submodel.SubModel;
import org.eclipse.aas.api.submodel.submodelelement.Operation;
import org.eclipse.aas.api.submodel.submodelelement.SubModelElementCollection;
@@ -346,34 +349,57 @@ public class DEWorkspaceCreator {
logger.error("Null Pointer Exception in fetching the Identifier Type of Property: " +
property.getIdShort());
}
-
- if (property.getEndpoint()!=null
- && property.getNameSpaceIndex() != 0
- && property.getIdentifier()!=null) {
+ Endpoint ep =property.getEndpoint();
+ ProtocolKind protocol = ep.getProtocol();
- if (identifierClass.getSimpleName().equals("String")) {
-
- defaultValue =
- "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
- + "this.connectedDevices."
- + property.getEndpoint().getName()
- + ".readValue(new NodeId(" + property.getNameSpaceIndex()
- + ", " + "\"" + property.getIdentifier() + "\"" + "))";
-
- }
+ if (property.getEndpoint()!=null ) {
- else {
-
- defaultValue =
- "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
- + "this.connectedDevices."
- + property.getEndpoint().getName()
- + ".readValue(new NodeId(" + property.getNameSpaceIndex()
- + ", " + property.getIdentifier() + "))";
-
- }
-
+ switch (protocol) {
+ case OPCUA :
+ generateOpcuaGetPropertyValue( property);
+ break;
+ case CoAP:
+ break;
+ case HTTP:
+ break;
+ case MQTT:
+ break;
+ case OTHER:
+ break;
+ case ROS:
+ break;
+ default:
+ break;
+ }
+
}
+// if (property.getEndpoint()!=null
+// && property.getNameSpaceIndex() != 0
+// && property.getIdentifier()!=null) {
+//
+// if (identifierClass.getSimpleName().equals("String")) {
+//
+// defaultValue =
+// "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
+// + "this.connectedDevices."
+// + property.getEndpoint().getName()
+// + ".readValue(new NodeId(" + property.getNameSpaceIndex()
+// + ", " + "\"" + property.getIdentifier() + "\"" + "))";
+//
+// }
+//
+// else {
+//
+// defaultValue =
+// "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
+// + "this.connectedDevices."
+// + property.getEndpoint().getName()
+// + ".readValue(new NodeId(" + property.getNameSpaceIndex()
+// + ", " + property.getIdentifier() + "))";
+//
+// }
+//
+// }
else if (property.getValue()!=null) {
@@ -417,6 +443,52 @@ public class DEWorkspaceCreator {
}
+ private String generateOpcuaGetPropertyValue(Property property) {
+ // Dynamic Property default value;
+ String defaultValue = "null";
+ Class<? extends Object> identifierClass = null;
+ // Determining the class of the NodeId Identifier:
+ try {
+ identifierClass = property.getIdentifier().getClass();
+ }
+ catch (NullPointerException e) {
+ logger.error("Null Pointer Exception in fetching the Identifier Type of Property: " +
+ property.getIdShort());
+ }
+ if (property.getEndpoint()!=null
+ && property.getNameSpaceIndex() != 0
+ && property.getIdentifier()!=null) {
+
+ if (identifierClass.getSimpleName().equals("String")) {
+
+ defaultValue =
+ "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
+ + "this.connectedDevices."
+ + property.getEndpoint().getName()
+ + ".readValue(new NodeId(" + property.getNameSpaceIndex()
+ + ", " + "\"" + property.getIdentifier() + "\"" + "))";
+
+ }
+
+ else {
+
+ defaultValue =
+ "(" + convertBaSyxToJavaTypes(property.getValueType()) + ") "
+ + "this.connectedDevices."
+ + property.getEndpoint().getName()
+ + ".readValue(new NodeId(" + property.getNameSpaceIndex()
+ + ", " + property.getIdentifier() + "))";
+
+ }
+
+ }
+
+ return defaultValue;
+ }
+
+
+
+
/**
* Generates the methods for those SubmodelElementCollections defined by user as "Dynamic".
* The output of these methods are then passed on to a {@code setGetHandler()} function
diff --git a/aas/plugins/modeling/org.eclipse.aas.api/src/org/eclipse/aas/api/communications/ProtocolKind.java b/aas/plugins/modeling/org.eclipse.aas.api/src/org/eclipse/aas/api/communications/ProtocolKind.java
index 2bb5867a..0cf37457 100644
--- a/aas/plugins/modeling/org.eclipse.aas.api/src/org/eclipse/aas/api/communications/ProtocolKind.java
+++ b/aas/plugins/modeling/org.eclipse.aas.api/src/org/eclipse/aas/api/communications/ProtocolKind.java
@@ -10,6 +10,7 @@
*
* Contributors:
* DFKI - Tapanta Bhanja <tapanta.bhanja@dfki.de>
+ * CEA LIST - Saadia DHOUIB <saadia.dhouib@cea.fr>
*******************************************************************************/
package org.eclipse.aas.api.communications;
@@ -19,6 +20,7 @@ public enum ProtocolKind {
MQTT,
OPCUA,
CoAP,
+ ROS,
OTHER
}
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.codegen.ui/src/org/eclipse/papyrus/aas/codegen/ui/handlers/GenerateAASCodeHelper.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.codegen.ui/src/org/eclipse/papyrus/aas/codegen/ui/handlers/GenerateAASCodeHelper.java
index 76fde4f5..d36a31d2 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.codegen.ui/src/org/eclipse/papyrus/aas/codegen/ui/handlers/GenerateAASCodeHelper.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.codegen.ui/src/org/eclipse/papyrus/aas/codegen/ui/handlers/GenerateAASCodeHelper.java
@@ -571,7 +571,7 @@ public class GenerateAASCodeHelper {
NodeId nodeid = stProperty.getNodeId();
if (nodeid != null) {
- submodelProperty.setNameSpaceIndex(nodeid.getNamespace());
+ submodelProperty.setNameSpaceIndex(nodeid.getNameSpaceIndex());
generateNodeId(nodeid, submodelProperty, null);
nodeidGenerated = true;
@@ -658,7 +658,7 @@ public class GenerateAASCodeHelper {
NodeId nodeid = stFile.getNodeId();
if (nodeid != null) {
- submodelFile.setNameSpaceIndex(nodeid.getNamespace());
+ submodelFile.setNameSpaceIndex(nodeid.getNameSpaceIndex());
generateNodeId(nodeid, null, submodelFile);
}
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/META-INF/MANIFEST.MF b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/META-INF/MANIFEST.MF
index 66e6482e..7800f875 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/META-INF/MANIFEST.MF
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/META-INF/MANIFEST.MF
@@ -3,7 +3,7 @@ Bundle-ManifestVersion: 2
Bundle-Name: %pluginName
Bundle-Vendor: %providerName
Bundle-SymbolicName: org.eclipse.papyrus.aas.profile;singleton:=true
-Bundle-Version: 0.8.0.qualifier
+Bundle-Version: 0.8.1.qualifier
Bundle-ClassPath: .
Bundle-Localization: plugin
Automatic-Module-Name: org.eclipse.papyrus.aas.profile
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/plugin.xml b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/plugin.xml
index aee1acf5..3e0a5f19 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/plugin.xml
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/plugin.xml
@@ -24,6 +24,7 @@
point="org.eclipse.papyrus.uml.extensionpoints.UMLProfile">
<profile
description="Asset Administration Shell Profile"
+ iconpath="resources/icons/AAS_16x16.png"
name="AASProfile"
path="pathmap://AAS_PROFILE/aas.profile.uml">
</profile>
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/pom.xml b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/pom.xml
index ad31b530..dcc00a2e 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/pom.xml
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/pom.xml
@@ -10,7 +10,7 @@
</parent>
<artifactId>org.eclipse.papyrus.aas.profile</artifactId>
- <version>0.8.0-SNAPSHOT</version>
+ <version>0.8.1-SNAPSHOT</version>
<packaging>eclipse-plugin</packaging>
</project> \ No newline at end of file
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.ecore b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.ecore
index 1ed40f3f..95007357 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.ecore
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.ecore
@@ -14,7 +14,7 @@
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="AssetAdministrationShell" eSuperTypes="#//Identifiable #//HasDataSpecification">
<eAnnotations source="http://www.eclipse.org/emf/2002/GenModel">
- <details key="documentation" value="A project in Basyx&#xD;&#xA;Basyx:&#xA;&#xA;identifierType: IRDI (urn:...), URI, custom &#xA;identifier (for submodel or operation) ->generated automatically&#xA;resource name&#xA;idshort: string -> generated automatically&#xA;category:string&#xA;description:string&#xA;parent: not used&#xA;administration: not used&#xA;&#xA;&#xA;&#xD;&#xA;Security is not implemented, but is an ongoing project&#xD;&#xA;0 &lt; port &lt;= 65535&#xA;"/>
+ <details key="documentation" value="A project in Basyx&#xA;Basyx:&#xA;&#xA;identifierType: IRDI (urn:...), URI, custom &#xA;identifier (for submodel or operation) ->generated automatically&#xA;resource name&#xA;idshort: string -> generated automatically&#xA;category:string&#xA;description:string&#xA;parent: not used&#xA;administration: not used&#xA;&#xA;&#xA;&#xA;Security is not implemented, but is an ongoing project&#xA;0 &lt; port &lt;= 65535&#xA;"/>
</eAnnotations>
<eStructuralFeatures xsi:type="ecore:EReference" name="derivedFrom" ordered="false"
eType="#//AssetAdministrationShell"/>
@@ -221,7 +221,7 @@
<eClassifiers xsi:type="ecore:EClass" name="AccessControl"/>
<eClassifiers xsi:type="ecore:EClass" name="Submodel" eSuperTypes="#//Identifiable #//HasKind #//HasSemantics #//HasDataSpecification">
<eAnnotations source="http://www.eclipse.org/emf/2002/GenModel">
- <details key="documentation" value="A model in Basyx&#xD;&#xA;Basyx:&#xA;&#xA;identifierType: IRDI (urn:...), URI, custom &#xA;identifier (for submodel or operation) ->generated automatically&#xA;resource name&#xA;idshort: string -> generated automatically&#xA;category:string&#xA;description:string&#xA;parent: not used&#xA;administration: not used&#xA;&#xA;&#xA;"/>
+ <details key="documentation" value="A model in Basyx&#xA;Basyx:&#xA;&#xA;identifierType: IRDI (urn:...), URI, custom &#xA;identifier (for submodel or operation) ->generated automatically&#xA;resource name&#xA;idshort: string -> generated automatically&#xA;category:string&#xA;description:string&#xA;parent: not used&#xA;administration: not used&#xA;&#xA;&#xA;"/>
</eAnnotations>
<eStructuralFeatures xsi:type="ecore:EReference" name="submodelelement" ordered="false"
upperBound="-1" eType="#//SubmodelElement" changeable="false" volatile="true"
@@ -277,15 +277,20 @@
<eLiterals name="MQTT" value="1"/>
<eLiterals name="OPCUA" value="2"/>
<eLiterals name="CoAP" value="3"/>
- <eLiterals name="OTHER" value="4"/>
+ <eLiterals name="ROS" value="4"/>
+ <eLiterals name="OTHER" value="5"/>
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="NodeId">
- <eStructuralFeatures xsi:type="ecore:EAttribute" name="namespace" ordered="false"
- lowerBound="1" eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//Integer"/>
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="topic" ordered="false"
+ eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//String"/>
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="nameSpace" ordered="false"
+ eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//String"/>
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="nameSpaceIndex" ordered="false"
+ eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//Integer"/>
<eStructuralFeatures xsi:type="ecore:EAttribute" name="identifier" ordered="false"
- lowerBound="1" eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//String"/>
+ eType="ecore:EDataType ../../org.eclipse.uml2.types/model/Types.ecore#//String"/>
<eStructuralFeatures xsi:type="ecore:EAttribute" name="idType" ordered="false"
- lowerBound="1" eType="#//IdType"/>
+ eType="#//IdType"/>
</eClassifiers>
<eClassifiers xsi:type="ecore:EEnum" name="IdType">
<eLiterals name="String"/>
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.genmodel b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.genmodel
index 042b7e3a..83014d75 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.genmodel
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.genmodel
@@ -140,6 +140,7 @@
<genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="aas.ecore#//ProtocolKind/MQTT"/>
<genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="aas.ecore#//ProtocolKind/OPCUA"/>
<genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="aas.ecore#//ProtocolKind/CoAP"/>
+ <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="aas.ecore#//ProtocolKind/ROS"/>
<genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="aas.ecore#//ProtocolKind/OTHER"/>
</genEnums>
<genEnums xsi:type="genmodel:GenEnum" typeSafeEnumCompatible="false" ecoreEnum="aas.ecore#//IdType">
@@ -309,7 +310,9 @@
<genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//Endpoint/name"/>
</genClasses>
<genClasses xsi:type="genmodel:GenClass" ecoreClass="aas.ecore#//NodeId">
- <genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/namespace"/>
+ <genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/topic"/>
+ <genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/nameSpace"/>
+ <genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/nameSpaceIndex"/>
<genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/identifier"/>
<genFeatures xsi:type="genmodel:GenFeature" createChild="false" ecoreFeature="ecore:EAttribute aas.ecore#//NodeId/idType"/>
</genClasses>
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.notation b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.notation
index 6383776c..9ca68b0b 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.notation
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.notation
@@ -1086,45 +1086,45 @@
<element xmi:type="uml:DataType" href="aas.profile.uml#_0icBACJ9EeuWq4zY-5mLEA"/>
<layoutConstraint xmi:type="notation:Bounds" xmi:id="_uAn6EV9AEeyEiuYeQkOPfw" x="-360" y="680"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_CC_lcO5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_CC_lce5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CC_lc-5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_IJ-ykJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_IJ-ykZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IJ-yk5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_CC_lcu5KEeyoD4-uOp3k9A" x="560" y="-180"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_IJ-ykpdTEe2SRMJBH-F_UQ" x="560" y="-180"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_CDKkk-5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_CDKklO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDKklu5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_IKPRQJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_IKPRQZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKPRQ5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_CDKkle5KEeyoD4-uOp3k9A" x="200" y="320"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_IKPRQpdTEe2SRMJBH-F_UQ" x="200" y="320"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_CDTHcO5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_CDTHce5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDTHc-5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_IKcFkJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_IKcFkZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKcFk5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Dependency"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_CDTHcu5KEeyoD4-uOp3k9A" x="760" y="860"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_IKcFkpdTEe2SRMJBH-F_UQ" x="760" y="860"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_CDZOEO5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_CDZOEe5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDZOE-5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_IKl2kJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_IKl2kZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKl2k5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#DataType"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_CDZOEu5KEeyoD4-uOp3k9A" x="-20" y="620"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_IKl2kpdTEe2SRMJBH-F_UQ" x="-20" y="620"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_CDcRY-5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_CDcRZO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDcRZu5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_IKrWIJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_IKrWIZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKrWI5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Package"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_CDcRZe5KEeyoD4-uOp3k9A" x="600" y="80"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_IKrWIpdTEe2SRMJBH-F_UQ" x="600" y="80"/>
</children>
<styles xmi:type="notation:StringValueStyle" xmi:id="_Nbw1EY7QEeqdQ5EKLtW6Vg" name="diagram_compatibility_version" stringValue="1.4.0"/>
<styles xmi:type="notation:DiagramStyle" xmi:id="_Nbw1Eo7QEeqdQ5EKLtW6Vg"/>
@@ -1524,55 +1524,55 @@
<sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_jy9OQBx7EeyfKaY8F4UOwQ" id="(1.0,0.6639004149377593)"/>
<targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_jy91UBx7EeyfKaY8F4UOwQ" id="(0.0,0.5555555555555556)"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_CC_ldO5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_3MuZ4JQbEeqsmLiGoCAZPQ" target="_CC_lcO5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_CC_lde5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CC_lee5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_IJ-ylJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_3MuZ4JQbEeqsmLiGoCAZPQ" target="_IJ-ykJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_IJ-ylZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IJ-ymZdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_CC_ldu5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CC_ld-5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CC_leO5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_IJ-ylpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IJ-yl5dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IJ-ymJdTEe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_CDLLoO5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_dawbMJj-EeqsmLiGoCAZPQ" target="_CDKkk-5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_CDLLoe5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDLLpe5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_IKPRRJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_dawbMJj-EeqsmLiGoCAZPQ" target="_IKPRQJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_IKPRRZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKPRSZdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_CDLLou5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDLLo-5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDLLpO5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_IKPRRpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKPRR5dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKPRSJdTEe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_CDTHdO5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_qhUkwKsFEeqnq7OKRN2fbg" target="_CDTHcO5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_CDTHde5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDTHee5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_IKcFlJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_qhUkwKsFEeqnq7OKRN2fbg" target="_IKcFkJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_IKcFlZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKcFmZdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Dependency"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_CDTHdu5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDTHd-5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDTHeO5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_IKcFlpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKcFl5dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKcFmJdTEe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_CDZOFO5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_XsV_cCJ9EeuWq4zY-5mLEA" target="_CDZOEO5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_CDZOFe5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDZOGe5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_IKl2lJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_XsV_cCJ9EeuWq4zY-5mLEA" target="_IKl2kJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_IKl2lZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKl2mZdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#DataType"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_CDZOFu5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDZOF-5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDZOGO5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_IKl2lpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKl2l5dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKl2mJdTEe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_CDcRZ-5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_uPPPAJ3LEeudPPrsLq2QgQ" target="_CDcRY-5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_CDcRaO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_CDcRbO5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_IKrWJJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_uPPPAJ3LEeudPPrsLq2QgQ" target="_IKrWIJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_IKrWJZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_IKr9MpdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Package"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_CDcRae5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDcRau5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_CDcRa-5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_IKrWJpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKr9MJdTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_IKr9MZdTEe2SRMJBH-F_UQ"/>
</edges>
</notation:Diagram>
<notation:Diagram xmi:id="_4Iu5sJj-EeqsmLiGoCAZPQ" type="PapyrusUMLProfileDiagram" name="Security" measurementUnit="Pixel">
@@ -1692,13 +1692,13 @@
<element xmi:type="uml:DataType" href="aas.profile.uml#_OlQfMJkBEeqsmLiGoCAZPQ"/>
<layoutConstraint xmi:type="notation:Bounds" xmi:id="_OlRtUZkBEeqsmLiGoCAZPQ" x="480" y="60"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_ccp7UymlEeurJuF7PIGu4w" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_ccp7VCmlEeurJuF7PIGu4w"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_ccqiYCmlEeurJuF7PIGu4w" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_igrA8JzOEe2lYI204K0p-Q" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_igrA8ZzOEe2lYI204K0p-Q"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_igrA85zOEe2lYI204K0p-Q" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_ccp7VSmlEeurJuF7PIGu4w" x="360" y="60"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_igrA8pzOEe2lYI204K0p-Q" x="360" y="60"/>
</children>
<styles xmi:type="notation:StringValueStyle" xmi:id="_4Iu5sZj-EeqsmLiGoCAZPQ" name="diagram_compatibility_version" stringValue="1.4.0"/>
<styles xmi:type="notation:DiagramStyle" xmi:id="_4Iu5spj-EeqsmLiGoCAZPQ"/>
@@ -1714,15 +1714,15 @@
<sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="__pFFsJj-EeqsmLiGoCAZPQ" id="(0.4225352112676056,0.0)"/>
<targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="__pFFsZj-EeqsmLiGoCAZPQ" id="(0.4,1.0)"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_ccqiYSmlEeurJuF7PIGu4w" type="StereotypeCommentLink" source="_-O18UJj-EeqsmLiGoCAZPQ" target="_ccp7UymlEeurJuF7PIGu4w">
- <styles xmi:type="notation:FontStyle" xmi:id="_ccqiYimlEeurJuF7PIGu4w"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_ccrJcimlEeurJuF7PIGu4w" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_igroAJzOEe2lYI204K0p-Q" type="StereotypeCommentLink" source="_-O18UJj-EeqsmLiGoCAZPQ" target="_igrA8JzOEe2lYI204K0p-Q">
+ <styles xmi:type="notation:FontStyle" xmi:id="_igroAZzOEe2lYI204K0p-Q"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_igroBZzOEe2lYI204K0p-Q" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_ccqiYymlEeurJuF7PIGu4w" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_ccrJcCmlEeurJuF7PIGu4w"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_ccrJcSmlEeurJuF7PIGu4w"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_igroApzOEe2lYI204K0p-Q" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_igroA5zOEe2lYI204K0p-Q"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_igroBJzOEe2lYI204K0p-Q"/>
</edges>
</notation:Diagram>
<css:ModelStyleSheets xmi:id="_xqwDYKr2EeqCiIVjjvsakg"/>
@@ -2323,29 +2323,29 @@
<element xmi:type="uml:Stereotype" href="aas.profile.uml#_Q2O20JXhEeqsmLiGoCAZPQ"/>
<layoutConstraint xmi:type="notation:Bounds" xmi:id="_1KFroW-dEeyZH7XFd9xCEQ" x="633" y="35" height="66"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_AP0-s-5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_AP0-tO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AP0-tu5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_yUlpEJdREe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_yUlpEZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yUlpE5dREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Operation"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_AP0-te5KEeyoD4-uOp3k9A" x="660" y="240"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_yUlpEpdREe2SRMJBH-F_UQ" x="660" y="240"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_AP4pEO5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_AP4pEe5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AP4pE-5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_yUs90JdREe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_yUs90ZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yUs905dREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Property"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_AP4pEu5KEeyoD4-uOp3k9A" x="300" y="100"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_yUs90pdREe2SRMJBH-F_UQ" x="300" y="100"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_AQBzA-5KEeyoD4-uOp3k9A" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_AQBzBO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AQBzBu5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_yU_RsJdREe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_yU_RsZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yU_Rs5dREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Property"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_AQBzBe5KEeyoD4-uOp3k9A" x="800" y="240"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_yU_RspdREe2SRMJBH-F_UQ" x="800" y="240"/>
</children>
<styles xmi:type="notation:StringValueStyle" xmi:id="_Q5ps0f2gEeqo7uz4QZ84uw" name="diagram_compatibility_version" stringValue="1.4.0"/>
<styles xmi:type="notation:DiagramStyle" xmi:id="_Q5ps0v2gEeqo7uz4QZ84uw"/>
@@ -2556,35 +2556,35 @@
<sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_2y8f0G-dEeyZH7XFd9xCEQ" id="(0.6284658040665434,0.0)"/>
<targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_2y8f0W-dEeyZH7XFd9xCEQ" id="(0.47,1.0)"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_AP0-t-5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_euudoP5NEeqmZsqm6Otq5g" target="_AP0-s-5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_AP0-uO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AP0-vO5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_yUmQIJdREe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_euudoP5NEeqmZsqm6Otq5g" target="_yUlpEJdREe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_yUmQIZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yUmQJZdREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Operation"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_AP0-ue5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AP0-uu5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AP0-u-5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_yUmQIpdREe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yUmQI5dREe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yUmQJJdREe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_AP4pFO5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_hfackP5NEeqmZsqm6Otq5g" target="_AP4pEO5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_AP4pFe5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AP4pGe5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_yUs91JdREe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_hfackP5NEeqmZsqm6Otq5g" target="_yUs90JdREe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_yUs91ZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yUs92ZdREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Property"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_AP4pFu5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AP4pF-5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AP4pGO5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_yUs91pdREe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yUs915dREe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yUs92JdREe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_AQBzB-5KEeyoD4-uOp3k9A" type="StereotypeCommentLink" source="_jHFhAP55EeqmZsqm6Otq5g" target="_AQBzA-5KEeyoD4-uOp3k9A">
- <styles xmi:type="notation:FontStyle" xmi:id="_AQBzCO5KEeyoD4-uOp3k9A"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_AQBzDO5KEeyoD4-uOp3k9A" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_yU_RtJdREe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_jHFhAP55EeqmZsqm6Otq5g" target="_yU_RsJdREe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_yU_RtZdREe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_yU_RuZdREe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Property"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_AQBzCe5KEeyoD4-uOp3k9A" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AQBzCu5KEeyoD4-uOp3k9A"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_AQBzC-5KEeyoD4-uOp3k9A"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_yU_RtpdREe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yU_Rt5dREe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_yU_RuJdREe2SRMJBH-F_UQ"/>
</edges>
</notation:Diagram>
<notation:Diagram xmi:id="_1IGRYP5jEeqmZsqm6Otq5g" type="PapyrusUMLProfileDiagram" name="Reference" measurementUnit="Pixel">
@@ -2973,6 +2973,10 @@
<element xmi:type="uml:EnumerationLiteral" href="aas.profile.uml#_Pu45UCKAEeuEAdH_l0B0vw"/>
<layoutConstraint xmi:type="notation:Location" xmi:id="_PvAOESKAEeuEAdH_l0B0vw"/>
</children>
+ <children xmi:type="notation:Shape" xmi:id="_LMo-YJdrEe2SRMJBH-F_UQ" type="EnumerationLiteral_LiteralLabel">
+ <element xmi:type="uml:EnumerationLiteral" href="aas.profile.uml#_LMIBAJdrEe2SRMJBH-F_UQ"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_LMo-YZdrEe2SRMJBH-F_UQ"/>
+ </children>
<styles xmi:type="notation:TitleStyle" xmi:id="_YAkGgSJ-EeuWq4zY-5mLEA"/>
<styles xmi:type="notation:SortingStyle" xmi:id="_YAkGgiJ-EeuWq4zY-5mLEA"/>
<styles xmi:type="notation:FilteringStyle" xmi:id="_YAkGgyJ-EeuWq4zY-5mLEA"/>
@@ -3053,6 +3057,43 @@
<element xmi:type="uml:DataType" href="aas.profile.uml#_t-Nx8NUCEeyUGt2LEMFOVg"/>
<layoutConstraint xmi:type="notation:Bounds" xmi:id="_t-VGsdUCEeyUGt2LEMFOVg" x="440" y="300"/>
</children>
+ <children xmi:type="notation:Shape" xmi:id="_O_mmkJdTEe2SRMJBH-F_UQ" type="DataType_Shape">
+ <children xmi:type="notation:DecorationNode" xmi:id="_O_obwJdTEe2SRMJBH-F_UQ" type="DataType_NameLabel"/>
+ <children xmi:type="notation:BasicCompartment" xmi:id="_O_obwZdTEe2SRMJBH-F_UQ" type="DataType_AttributeCompartment">
+ <children xmi:type="notation:Shape" xmi:id="_m59F4JdeEe2SRMJBH-F_UQ" type="Property_DataTypeAttributeLabel">
+ <element xmi:type="uml:Property" href="aas.profile.uml#_m5J0oJdeEe2SRMJBH-F_UQ"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_m59F4ZdeEe2SRMJBH-F_UQ"/>
+ </children>
+ <children xmi:type="notation:Shape" xmi:id="_S2W1sJdTEe2SRMJBH-F_UQ" type="Property_DataTypeAttributeLabel">
+ <element xmi:type="uml:Property" href="aas.profile.uml#_AnDzEF8oEeyEiuYeQkOPfw"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_S2W1sZdTEe2SRMJBH-F_UQ"/>
+ </children>
+ <children xmi:type="notation:Shape" xmi:id="_TVlIUJdTEe2SRMJBH-F_UQ" type="Property_DataTypeAttributeLabel">
+ <element xmi:type="uml:Property" href="aas.profile.uml#_MwC-IF8oEeyEiuYeQkOPfw"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_TVlIUZdTEe2SRMJBH-F_UQ"/>
+ </children>
+ <children xmi:type="notation:Shape" xmi:id="_TtcOsJdTEe2SRMJBH-F_UQ" type="Property_DataTypeAttributeLabel">
+ <element xmi:type="uml:Property" href="aas.profile.uml#_x0-5EGJMEeyEiuYeQkOPfw"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_TtcOsZdTEe2SRMJBH-F_UQ"/>
+ </children>
+ <children xmi:type="notation:Shape" xmi:id="_kzgjEJfoEe2SRMJBH-F_UQ" type="Property_DataTypeAttributeLabel">
+ <element xmi:type="uml:Property" href="aas.profile.uml#_ky77UJfoEe2SRMJBH-F_UQ"/>
+ <layoutConstraint xmi:type="notation:Location" xmi:id="_kzgjEZfoEe2SRMJBH-F_UQ"/>
+ </children>
+ <styles xmi:type="notation:TitleStyle" xmi:id="_O_obwpdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:SortingStyle" xmi:id="_O_obw5dTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:FilteringStyle" xmi:id="_O_obxJdTEe2SRMJBH-F_UQ"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_O_obxZdTEe2SRMJBH-F_UQ"/>
+ </children>
+ <children xmi:type="notation:BasicCompartment" xmi:id="_O_obxpdTEe2SRMJBH-F_UQ" type="DataType_OperationCompartment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_O_obx5dTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:SortingStyle" xmi:id="_O_obyJdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:FilteringStyle" xmi:id="_O_obyZdTEe2SRMJBH-F_UQ"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_O_obypdTEe2SRMJBH-F_UQ"/>
+ </children>
+ <element xmi:type="uml:DataType" href="aas.profile.uml#_-FspkF8nEeyEiuYeQkOPfw"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_O_mmkZdTEe2SRMJBH-F_UQ" x="60" y="380"/>
+ </children>
<styles xmi:type="notation:StringValueStyle" xmi:id="_0DuEsSJ9EeuWq4zY-5mLEA" name="diagram_compatibility_version" stringValue="1.4.0"/>
<styles xmi:type="notation:DiagramStyle" xmi:id="_0DuEsiJ9EeuWq4zY-5mLEA"/>
<styles xmi:type="style:PapyrusDiagramStyle" xmi:id="_0DuEsyJ9EeuWq4zY-5mLEA" diagramKindId="org.eclipse.papyrus.uml.diagram.profile">
@@ -3509,21 +3550,21 @@
<element xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#ValueSpecification"/>
<layoutConstraint xmi:type="notation:Bounds" xmi:id="_8MUMUxxbEeyfKaY8F4UOwQ" x="800" y="260"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_fp2bupl-EeyMEefTcnapKg" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_fp2bu5l-EeyMEefTcnapKg"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_fp2bvZl-EeyMEefTcnapKg" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_Gvi04JdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_Gvi04ZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_Gvi045dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_fp2bvJl-EeyMEefTcnapKg" x="600" y="280"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_Gvi04pdTEe2SRMJBH-F_UQ" x="600" y="280"/>
</children>
- <children xmi:type="notation:Shape" xmi:id="_fp2b3Jl-EeyMEefTcnapKg" type="StereotypeComment">
- <styles xmi:type="notation:TitleStyle" xmi:id="_fp2b3Zl-EeyMEefTcnapKg"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_fqAMsJl-EeyMEefTcnapKg" name="BASE_ELEMENT">
+ <children xmi:type="notation:Shape" xmi:id="_GvrXwJdTEe2SRMJBH-F_UQ" type="StereotypeComment">
+ <styles xmi:type="notation:TitleStyle" xmi:id="_GvrXwZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_GvrXw5dTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#ValueSpecification"/>
</styles>
<element xsi:nil="true"/>
- <layoutConstraint xmi:type="notation:Bounds" xmi:id="_fp2b3pl-EeyMEefTcnapKg" x="1000" y="260"/>
+ <layoutConstraint xmi:type="notation:Bounds" xmi:id="_GvrXwpdTEe2SRMJBH-F_UQ" x="1000" y="260"/>
</children>
<styles xmi:type="notation:StringValueStyle" xmi:id="_0xWwQRxTEeyfKaY8F4UOwQ" name="diagram_compatibility_version" stringValue="1.4.0"/>
<styles xmi:type="notation:DiagramStyle" xmi:id="_0xWwQhxTEeyfKaY8F4UOwQ"/>
@@ -3538,25 +3579,25 @@
<sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_lC4PwBxUEeyfKaY8F4UOwQ" id="(0.32432432432432434,0.0)"/>
<targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_lC4PwRxUEeyfKaY8F4UOwQ" id="(0.4,1.0)"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_fp2bvpl-EeyMEefTcnapKg" type="StereotypeCommentLink" source="_kMh2kBxUEeyfKaY8F4UOwQ" target="_fp2bupl-EeyMEefTcnapKg">
- <styles xmi:type="notation:FontStyle" xmi:id="_fp2bv5l-EeyMEefTcnapKg"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_fp2bw5l-EeyMEefTcnapKg" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_Gvi05JdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_kMh2kBxUEeyfKaY8F4UOwQ" target="_Gvi04JdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_Gvi05ZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_Gvjb8JdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#Class"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_fp2bwJl-EeyMEefTcnapKg" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_fp2bwZl-EeyMEefTcnapKg"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_fp2bwpl-EeyMEefTcnapKg"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_Gvi05pdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_Gvi055dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_Gvi06JdTEe2SRMJBH-F_UQ"/>
</edges>
- <edges xmi:type="notation:Connector" xmi:id="_fqAMsZl-EeyMEefTcnapKg" type="StereotypeCommentLink" source="_8MUMUBxbEeyfKaY8F4UOwQ" target="_fp2b3Jl-EeyMEefTcnapKg">
- <styles xmi:type="notation:FontStyle" xmi:id="_fqAMspl-EeyMEefTcnapKg"/>
- <styles xmi:type="notation:EObjectValueStyle" xmi:id="_fqAMtpl-EeyMEefTcnapKg" name="BASE_ELEMENT">
+ <edges xmi:type="notation:Connector" xmi:id="_GvrXxJdTEe2SRMJBH-F_UQ" type="StereotypeCommentLink" source="_8MUMUBxbEeyfKaY8F4UOwQ" target="_GvrXwJdTEe2SRMJBH-F_UQ">
+ <styles xmi:type="notation:FontStyle" xmi:id="_GvrXxZdTEe2SRMJBH-F_UQ"/>
+ <styles xmi:type="notation:EObjectValueStyle" xmi:id="_GvrXyZdTEe2SRMJBH-F_UQ" name="BASE_ELEMENT">
<eObjectValue xmi:type="uml:Class" href="pathmap://UML_METAMODELS/UML.metamodel.uml#ValueSpecification"/>
</styles>
<element xsi:nil="true"/>
- <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_fqAMs5l-EeyMEefTcnapKg" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
- <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_fqAMtJl-EeyMEefTcnapKg"/>
- <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_fqAMtZl-EeyMEefTcnapKg"/>
+ <bendpoints xmi:type="notation:RelativeBendpoints" xmi:id="_GvrXxpdTEe2SRMJBH-F_UQ" points="[0, 0, 0, 0]$[0, 0, 0, 0]"/>
+ <sourceAnchor xmi:type="notation:IdentityAnchor" xmi:id="_GvrXx5dTEe2SRMJBH-F_UQ"/>
+ <targetAnchor xmi:type="notation:IdentityAnchor" xmi:id="_GvrXyJdTEe2SRMJBH-F_UQ"/>
</edges>
</notation:Diagram>
<notation:Diagram xmi:id="_WipoEBx2EeyfKaY8F4UOwQ" type="PapyrusUMLProfileDiagram" name="View" measurementUnit="Pixel">
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.uml b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.uml
index c614bbb2..ad10ef56 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.uml
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/aas.profile.uml
@@ -548,6 +548,7 @@ default values are localhost and 5125</body>
<ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_Ja_SUCKAEeuEAdH_l0B0vw" name="MQTT"/>
<ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_KPG24CKAEeuEAdH_l0B0vw" name="OPCUA"/>
<ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_MugRgCKAEeuEAdH_l0B0vw" name="CoAP"/>
+ <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_LMIBAJdrEe2SRMJBH-F_UQ" name="ROS"/>
<ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_Pu45UCKAEeuEAdH_l0B0vw" name="OTHER"/>
</packagedElement>
<packagedElement xmi:type="uml:Stereotype" xmi:id="_jQstgGF1EeuDR7fZChdWmQ" name="ConceptDescription">
@@ -750,13 +751,25 @@ default values are localhost and 5125</body>
</ownedAttribute>
</packagedElement>
<packagedElement xmi:type="uml:DataType" xmi:id="_-FspkF8nEeyEiuYeQkOPfw" name="NodeId">
- <ownedAttribute xmi:type="uml:Property" xmi:id="_AnDzEF8oEeyEiuYeQkOPfw" name="namespace">
+ <ownedAttribute xmi:type="uml:Property" xmi:id="_ky77UJfoEe2SRMJBH-F_UQ" name="topic">
+ <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
+ <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_06GG8Jf6Ee2SRMJBH-F_UQ"/>
+ </ownedAttribute>
+ <ownedAttribute xmi:type="uml:Property" xmi:id="_m5J0oJdeEe2SRMJBH-F_UQ" name="nameSpace">
+ <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
+ <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_q6ucIJzOEe2lYI204K0p-Q"/>
+ </ownedAttribute>
+ <ownedAttribute xmi:type="uml:Property" xmi:id="_AnDzEF8oEeyEiuYeQkOPfw" name="nameSpaceIndex">
<type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#Integer"/>
+ <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_4LBFIJf6Ee2SRMJBH-F_UQ"/>
</ownedAttribute>
<ownedAttribute xmi:type="uml:Property" xmi:id="_MwC-IF8oEeyEiuYeQkOPfw" name="identifier">
<type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
+ <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_4-_fwJf6Ee2SRMJBH-F_UQ"/>
+ </ownedAttribute>
+ <ownedAttribute xmi:type="uml:Property" xmi:id="_x0-5EGJMEeyEiuYeQkOPfw" name="idType" visibility="public" type="_9wzx4GJMEeyEiuYeQkOPfw">
+ <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_5w7TAJf6Ee2SRMJBH-F_UQ"/>
</ownedAttribute>
- <ownedAttribute xmi:type="uml:Property" xmi:id="_x0-5EGJMEeyEiuYeQkOPfw" name="idType" visibility="public" type="_9wzx4GJMEeyEiuYeQkOPfw"/>
</packagedElement>
<packagedElement xmi:type="uml:Enumeration" xmi:id="_9wzx4GJMEeyEiuYeQkOPfw" name="IdType">
<ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_DrRlMGJNEeyEiuYeQkOPfw" name="String"/>
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/icons/AAS_16x16.png b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/icons/AAS_16x16.png
new file mode 100644
index 00000000..ff6bd0ef
--- /dev/null
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/resources/icons/AAS_16x16.png
Binary files differ
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/ProtocolKind.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/ProtocolKind.java
index cdeff992..988ee351 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/ProtocolKind.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/ProtocolKind.java
@@ -70,6 +70,14 @@ public enum ProtocolKind implements Enumerator {
CO_AP(3, "CoAP", "CoAP"),
/**
+ * The '<em><b>ROS</b></em>' literal object.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #ROS_VALUE
+ * @generated
+ * @ordered
+ */
+ ROS(4, "ROS", "ROS"), /**
* The '<em><b>OTHER</b></em>' literal object.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -77,7 +85,7 @@ public enum ProtocolKind implements Enumerator {
* @generated
* @ordered
*/
- OTHER(4, "OTHER", "OTHER");
+ OTHER(5, "OTHER", "OTHER");
/**
* The '<em><b>HTTP</b></em>' literal value.
@@ -124,6 +132,17 @@ public enum ProtocolKind implements Enumerator {
public static final int CO_AP_VALUE = 3;
/**
+ * The '<em><b>ROS</b></em>' literal value.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #ROS
+ * @model
+ * @generated
+ * @ordered
+ */
+ public static final int ROS_VALUE = 4;
+
+ /**
* The '<em><b>OTHER</b></em>' literal value.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -132,7 +151,7 @@ public enum ProtocolKind implements Enumerator {
* @generated
* @ordered
*/
- public static final int OTHER_VALUE = 4;
+ public static final int OTHER_VALUE = 5;
/**
* An array of all the '<em><b>Protocol Kind</b></em>' enumerators.
@@ -146,6 +165,7 @@ public enum ProtocolKind implements Enumerator {
MQTT,
OPCUA,
CO_AP,
+ ROS,
OTHER,
};
@@ -207,6 +227,7 @@ public enum ProtocolKind implements Enumerator {
case MQTT_VALUE: return MQTT;
case OPCUA_VALUE: return OPCUA;
case CO_AP_VALUE: return CO_AP;
+ case ROS_VALUE: return ROS;
case OTHER_VALUE: return OTHER;
}
return null;
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/AASPackageImpl.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/AASPackageImpl.java
index 93f24757..a5245901 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/AASPackageImpl.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/AASPackageImpl.java
@@ -1213,7 +1213,7 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
* @generated
*/
@Override
- public EAttribute getNodeId_Namespace() {
+ public EAttribute getNodeId_Topic() {
return (EAttribute)nodeIdEClass.getEStructuralFeatures().get(0);
}
@@ -1223,7 +1223,7 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
* @generated
*/
@Override
- public EAttribute getNodeId_Identifier() {
+ public EAttribute getNodeId_NameSpace() {
return (EAttribute)nodeIdEClass.getEStructuralFeatures().get(1);
}
@@ -1233,7 +1233,7 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
* @generated
*/
@Override
- public EAttribute getNodeId_IdType() {
+ public EAttribute getNodeId_NameSpaceIndex() {
return (EAttribute)nodeIdEClass.getEStructuralFeatures().get(2);
}
@@ -1243,6 +1243,26 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
* @generated
*/
@Override
+ public EAttribute getNodeId_Identifier() {
+ return (EAttribute)nodeIdEClass.getEStructuralFeatures().get(3);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public EAttribute getNodeId_IdType() {
+ return (EAttribute)nodeIdEClass.getEStructuralFeatures().get(4);
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
public EClass getCertificate() {
return certificateEClass;
}
@@ -2248,7 +2268,9 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
createEAttribute(endpointEClass, ENDPOINT__NAME);
nodeIdEClass = createEClass(NODE_ID);
- createEAttribute(nodeIdEClass, NODE_ID__NAMESPACE);
+ createEAttribute(nodeIdEClass, NODE_ID__TOPIC);
+ createEAttribute(nodeIdEClass, NODE_ID__NAME_SPACE);
+ createEAttribute(nodeIdEClass, NODE_ID__NAME_SPACE_INDEX);
createEAttribute(nodeIdEClass, NODE_ID__IDENTIFIER);
createEAttribute(nodeIdEClass, NODE_ID__ID_TYPE);
@@ -2517,9 +2539,11 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
initEAttribute(getEndpoint_Name(), theTypesPackage.getString(), "name", null, 0, 1, Endpoint.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
initEClass(nodeIdEClass, NodeId.class, "NodeId", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
- initEAttribute(getNodeId_Namespace(), theTypesPackage.getInteger(), "namespace", null, 1, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEAttribute(getNodeId_Identifier(), theTypesPackage.getString(), "identifier", null, 1, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
- initEAttribute(getNodeId_IdType(), this.getIdType(), "idType", null, 1, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getNodeId_Topic(), theTypesPackage.getString(), "topic", null, 0, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getNodeId_NameSpace(), theTypesPackage.getString(), "nameSpace", null, 0, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getNodeId_NameSpaceIndex(), theTypesPackage.getInteger(), "nameSpaceIndex", null, 0, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getNodeId_Identifier(), theTypesPackage.getString(), "identifier", null, 0, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
+ initEAttribute(getNodeId_IdType(), this.getIdType(), "idType", null, 0, 1, NodeId.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, !IS_ORDERED);
initEClass(certificateEClass, Certificate.class, "Certificate", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
@@ -2727,6 +2751,7 @@ public class AASPackageImpl extends EPackageImpl implements AASPackage {
addEEnumLiteral(protocolKindEEnum, ProtocolKind.MQTT);
addEEnumLiteral(protocolKindEEnum, ProtocolKind.OPCUA);
addEEnumLiteral(protocolKindEEnum, ProtocolKind.CO_AP);
+ addEEnumLiteral(protocolKindEEnum, ProtocolKind.ROS);
addEEnumLiteral(protocolKindEEnum, ProtocolKind.OTHER);
initEEnum(idTypeEEnum, IdType.class, "IdType");
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/NodeIdImpl.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/NodeIdImpl.java
index 9d32bb52..8efb0aee 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/NodeIdImpl.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/impl/NodeIdImpl.java
@@ -32,7 +32,9 @@ import org.eclipse.papyrus.aas.NodeId;
* The following features are implemented:
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getNamespace <em>Namespace</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getTopic <em>Topic</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getNameSpace <em>Name Space</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getNameSpaceIndex <em>Name Space Index</em>}</li>
* <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getIdentifier <em>Identifier</em>}</li>
* <li>{@link org.eclipse.papyrus.aas.impl.NodeIdImpl#getIdType <em>Id Type</em>}</li>
* </ul>
@@ -41,24 +43,64 @@ import org.eclipse.papyrus.aas.NodeId;
*/
public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
/**
- * The default value of the '{@link #getNamespace() <em>Namespace</em>}' attribute.
+ * The default value of the '{@link #getTopic() <em>Topic</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getNamespace()
+ * @see #getTopic()
* @generated
* @ordered
*/
- protected static final int NAMESPACE_EDEFAULT = 0;
+ protected static final String TOPIC_EDEFAULT = null;
/**
- * The cached value of the '{@link #getNamespace() <em>Namespace</em>}' attribute.
+ * The cached value of the '{@link #getTopic() <em>Topic</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getNamespace()
+ * @see #getTopic()
* @generated
* @ordered
*/
- protected int namespace = NAMESPACE_EDEFAULT;
+ protected String topic = TOPIC_EDEFAULT;
+
+ /**
+ * The default value of the '{@link #getNameSpace() <em>Name Space</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getNameSpace()
+ * @generated
+ * @ordered
+ */
+ protected static final String NAME_SPACE_EDEFAULT = null;
+
+ /**
+ * The cached value of the '{@link #getNameSpace() <em>Name Space</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getNameSpace()
+ * @generated
+ * @ordered
+ */
+ protected String nameSpace = NAME_SPACE_EDEFAULT;
+
+ /**
+ * The default value of the '{@link #getNameSpaceIndex() <em>Name Space Index</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getNameSpaceIndex()
+ * @generated
+ * @ordered
+ */
+ protected static final int NAME_SPACE_INDEX_EDEFAULT = 0;
+
+ /**
+ * The cached value of the '{@link #getNameSpaceIndex() <em>Name Space Index</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @see #getNameSpaceIndex()
+ * @generated
+ * @ordered
+ */
+ protected int nameSpaceIndex = NAME_SPACE_INDEX_EDEFAULT;
/**
* The default value of the '{@link #getIdentifier() <em>Identifier</em>}' attribute.
@@ -125,8 +167,21 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
* @generated
*/
@Override
- public int getNamespace() {
- return namespace;
+ public String getTopic() {
+ return topic;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public void setTopic(String newTopic) {
+ String oldTopic = topic;
+ topic = newTopic;
+ if (eNotificationRequired())
+ eNotify(new ENotificationImpl(this, Notification.SET, AASPackage.NODE_ID__TOPIC, oldTopic, topic));
}
/**
@@ -135,11 +190,44 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
* @generated
*/
@Override
- public void setNamespace(int newNamespace) {
- int oldNamespace = namespace;
- namespace = newNamespace;
+ public String getNameSpace() {
+ return nameSpace;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public void setNameSpace(String newNameSpace) {
+ String oldNameSpace = nameSpace;
+ nameSpace = newNameSpace;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, AASPackage.NODE_ID__NAMESPACE, oldNamespace, namespace));
+ eNotify(new ENotificationImpl(this, Notification.SET, AASPackage.NODE_ID__NAME_SPACE, oldNameSpace, nameSpace));
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public int getNameSpaceIndex() {
+ return nameSpaceIndex;
+ }
+
+ /**
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ @Override
+ public void setNameSpaceIndex(int newNameSpaceIndex) {
+ int oldNameSpaceIndex = nameSpaceIndex;
+ nameSpaceIndex = newNameSpaceIndex;
+ if (eNotificationRequired())
+ eNotify(new ENotificationImpl(this, Notification.SET, AASPackage.NODE_ID__NAME_SPACE_INDEX, oldNameSpaceIndex, nameSpaceIndex));
}
/**
@@ -196,8 +284,12 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
@Override
public Object eGet(int featureID, boolean resolve, boolean coreType) {
switch (featureID) {
- case AASPackage.NODE_ID__NAMESPACE:
- return getNamespace();
+ case AASPackage.NODE_ID__TOPIC:
+ return getTopic();
+ case AASPackage.NODE_ID__NAME_SPACE:
+ return getNameSpace();
+ case AASPackage.NODE_ID__NAME_SPACE_INDEX:
+ return getNameSpaceIndex();
case AASPackage.NODE_ID__IDENTIFIER:
return getIdentifier();
case AASPackage.NODE_ID__ID_TYPE:
@@ -214,8 +306,14 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
@Override
public void eSet(int featureID, Object newValue) {
switch (featureID) {
- case AASPackage.NODE_ID__NAMESPACE:
- setNamespace((Integer)newValue);
+ case AASPackage.NODE_ID__TOPIC:
+ setTopic((String)newValue);
+ return;
+ case AASPackage.NODE_ID__NAME_SPACE:
+ setNameSpace((String)newValue);
+ return;
+ case AASPackage.NODE_ID__NAME_SPACE_INDEX:
+ setNameSpaceIndex((Integer)newValue);
return;
case AASPackage.NODE_ID__IDENTIFIER:
setIdentifier((String)newValue);
@@ -235,8 +333,14 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
@Override
public void eUnset(int featureID) {
switch (featureID) {
- case AASPackage.NODE_ID__NAMESPACE:
- setNamespace(NAMESPACE_EDEFAULT);
+ case AASPackage.NODE_ID__TOPIC:
+ setTopic(TOPIC_EDEFAULT);
+ return;
+ case AASPackage.NODE_ID__NAME_SPACE:
+ setNameSpace(NAME_SPACE_EDEFAULT);
+ return;
+ case AASPackage.NODE_ID__NAME_SPACE_INDEX:
+ setNameSpaceIndex(NAME_SPACE_INDEX_EDEFAULT);
return;
case AASPackage.NODE_ID__IDENTIFIER:
setIdentifier(IDENTIFIER_EDEFAULT);
@@ -256,8 +360,12 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
@Override
public boolean eIsSet(int featureID) {
switch (featureID) {
- case AASPackage.NODE_ID__NAMESPACE:
- return namespace != NAMESPACE_EDEFAULT;
+ case AASPackage.NODE_ID__TOPIC:
+ return TOPIC_EDEFAULT == null ? topic != null : !TOPIC_EDEFAULT.equals(topic);
+ case AASPackage.NODE_ID__NAME_SPACE:
+ return NAME_SPACE_EDEFAULT == null ? nameSpace != null : !NAME_SPACE_EDEFAULT.equals(nameSpace);
+ case AASPackage.NODE_ID__NAME_SPACE_INDEX:
+ return nameSpaceIndex != NAME_SPACE_INDEX_EDEFAULT;
case AASPackage.NODE_ID__IDENTIFIER:
return IDENTIFIER_EDEFAULT == null ? identifier != null : !IDENTIFIER_EDEFAULT.equals(identifier);
case AASPackage.NODE_ID__ID_TYPE:
@@ -276,8 +384,12 @@ public class NodeIdImpl extends MinimalEObjectImpl.Container implements NodeId {
if (eIsProxy()) return super.toString();
StringBuilder result = new StringBuilder(super.toString());
- result.append(" (namespace: ");
- result.append(namespace);
+ result.append(" (topic: ");
+ result.append(topic);
+ result.append(", nameSpace: ");
+ result.append(nameSpace);
+ result.append(", nameSpaceIndex: ");
+ result.append(nameSpaceIndex);
result.append(", identifier: ");
result.append(identifier);
result.append(", idType: ");
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.designer.languages.java.codegen/src/org/eclipse/papyrus/designer/languages/java/codegen/utils/JavaGenUtils.java b/aas/plugins/modeling/org.eclipse.papyrus.designer.languages.java.codegen/src/org/eclipse/papyrus/designer/languages/java/codegen/utils/JavaGenUtils.java
index 3680d2be..e8b01ed4 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.designer.languages.java.codegen/src/org/eclipse/papyrus/designer/languages/java/codegen/utils/JavaGenUtils.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.designer.languages.java.codegen/src/org/eclipse/papyrus/designer/languages/java/codegen/utils/JavaGenUtils.java
@@ -531,7 +531,7 @@ public class JavaGenUtils {
if (hasNodeId(property)) {
org.eclipse.papyrus.aas.Property aasProp = UMLUtil.getStereotypeApplication(property,
org.eclipse.papyrus.aas.Property.class);
- return aasProp.getNodeId().getNamespace();
+ return aasProp.getNodeId().getNameSpaceIndex();
}
return 0;

Back to the top
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/AASPackage.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/AASPackage.java
index c5f810fb..6aeb066d 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/AASPackage.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/AASPackage.java
@@ -1276,13 +1276,31 @@ public interface AASPackage extends EPackage {
int NODE_ID = 17;
/**
* The feature id for the '<em><b>Namespace</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int NODE_ID__NAMESPACE = 0;
+ int NODE_ID__TOPIC = 0;
+
+ /**
+ * The feature id for the '<em><b>Name Space</b></em>' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ * @ordered
+ */
+ int NODE_ID__NAME_SPACE = 1;
+
+ /**
+ * The feature id for the '<em><b>Name Space Index</b></em>' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ * @ordered
+ */
+ int NODE_ID__NAME_SPACE_INDEX = 2;
/**
* The feature id for the '<em><b>Identifier</b></em>' attribute.
@@ -1291,7 +1309,7 @@ public interface AASPackage extends EPackage {
* @generated
* @ordered
*/
- int NODE_ID__IDENTIFIER = 1;
+ int NODE_ID__IDENTIFIER = 3;
/**
* The feature id for the '<em><b>Id Type</b></em>' attribute.
@@ -1300,7 +1318,7 @@ public interface AASPackage extends EPackage {
* @generated
* @ordered
*/
- int NODE_ID__ID_TYPE = 2;
+ int NODE_ID__ID_TYPE = 4;
/**
* The number of structural features of the '<em>Node Id</em>' class.
@@ -1309,7 +1327,7 @@ public interface AASPackage extends EPackage {
* @generated
* @ordered
*/
- int NODE_ID_FEATURE_COUNT = 3;
+ int NODE_ID_FEATURE_COUNT = 5;
/**
* The number of operations of the '<em>Node Id</em>' class.
@@ -4983,15 +5001,37 @@ public interface AASPackage extends EPackage {
EClass getNodeId();
/**
- * Returns the meta object for the attribute '{@link org.eclipse.papyrus.aas.NodeId#getNamespace <em>Namespace</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.aas.NodeId#getTopic <em>Topic</em>}'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return the meta object for the attribute '<em>Topic</em>'.
+ * @see org.eclipse.papyrus.aas.NodeId#getTopic()
+ * @see #getNodeId()
+ * @generated
+ */
+ EAttribute getNodeId_Topic();
+
+ /**
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.aas.NodeId#getNameSpace <em>Name Space</em>}'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return the meta object for the attribute '<em>Name Space</em>'.
+ * @see org.eclipse.papyrus.aas.NodeId#getNameSpace()
+ * @see #getNodeId()
+ * @generated
+ */
+ EAttribute getNodeId_NameSpace();
+
+ /**
+ * Returns the meta object for the attribute '{@link org.eclipse.papyrus.aas.NodeId#getNameSpaceIndex <em>Name Space Index</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Namespace</em>'.
* @see org.eclipse.papyrus.aas.NodeId#getNamespace()
* @see #getNodeId()
* @generated
*/
- EAttribute getNodeId_Namespace();
+ EAttribute getNodeId_NameSpaceIndex();
/**
* Returns the meta object for the attribute '{@link org.eclipse.papyrus.aas.NodeId#getIdentifier <em>Identifier</em>}'.
@@ -6546,12 +6586,28 @@ public interface AASPackage extends EPackage {
EClass NODE_ID = eINSTANCE.getNodeId();
/**
- * The meta object literal for the '<em><b>Namespace</b></em>' attribute feature.
+ * The meta object literal for the '<em><b>Topic</b></em>' attribute feature.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ EAttribute NODE_ID__TOPIC = eINSTANCE.getNodeId_Topic();
+
+ /**
+ * The meta object literal for the '<em><b>Name Space</b></em>' attribute feature.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ EAttribute NODE_ID__NAME_SPACE = eINSTANCE.getNodeId_NameSpace();
+
+ /**
+ * The meta object literal for the '<em><b>Name Space Index</b></em>' attribute feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- EAttribute NODE_ID__NAMESPACE = eINSTANCE.getNodeId_Namespace();
+ EAttribute NODE_ID__NAME_SPACE_INDEX = eINSTANCE.getNodeId_NameSpaceIndex();
/**
* The meta object literal for the '<em><b>Identifier</b></em>' attribute feature.
@@ -1276,13 +1276,31 @@ public interface AASPackage extends EPackage {
int NODE_ID = 17;
/**
- * The feature id for the '<em><b>Namespace</b></em>' attribute.
+ * The feature id for the '<em><b>Topic</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -4983,15 +5001,37 @@ public interface AASPackage extends EPackage {
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the attribute '<em>Namespace</em>'.
- * @see org.eclipse.papyrus.aas.NodeId#getNamespace()
+ * @return the meta object for the attribute '<em>Name Space Index</em>'.
+ * @see org.eclipse.papyrus.aas.NodeId#getNameSpaceIndex()
* @see #getNodeId()
* @generated
diff --git a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/NodeId.java b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/NodeId.java
index f8396688..27a14e87 100644
--- a/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/NodeId.java
+++ b/aas/plugins/modeling/org.eclipse.papyrus.aas.profile/src/org/eclipse/papyrus/aas/NodeId.java
@@ -24,7 +24,9 @@ import org.eclipse.emf.ecore.EObject;
* The following features are supported:
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.aas.NodeId#getNamespace <em>Namespace</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.NodeId#getTopic <em>Topic</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.NodeId#getNameSpace <em>Name Space</em>}</li>
+ * <li>{@link org.eclipse.papyrus.aas.NodeId#getNameSpaceIndex <em>Name Space Index</em>}</li>
* <li>{@link org.eclipse.papyrus.aas.NodeId#getIdentifier <em>Identifier</em>}</li>
* <li>{@link org.eclipse.papyrus.aas.NodeId#getIdType <em>Id Type</em>}</li>
* </ul>
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
*/
public interface NodeId extends EObject {
/**
* Returns the value of the '<em><b>Namespace</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Namespace</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Namespace</em>' attribute.
* @see #setNamespace(int)
* @see org.eclipse.papyrus.aas.AASPackage#getNodeId_Namespace()
* @model dataType="org.eclipse.uml2.types.Integer" required="true" ordered="false"
* @generated
*/
- int getNamespace();
+ String getTopic();
/**
* Sets the value of the '{@link org.eclipse.papyrus.aas.NodeId#getNamespace <em>Namespace</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Namespace</em>' attribute.
* @see #getNamespace()
* @generated
*/
- void setNamespace(int value);
+ void setTopic(String value);
+
+ /**
+ * Returns the value of the '<em><b>Name Space</b></em>' attribute.
+ * <!-- begin-user-doc -->
+ * <p>
+ * If the meaning of the '<em>Name Space</em>' attribute isn't clear,
+ * there really should be more of a description here...
+ * </p>
+ * <!-- end-user-doc -->
+ * @return the value of the '<em>Name Space</em>' attribute.
+ * @see #setNameSpace(String)
+ * @see org.eclipse.papyrus.aas.AASPackage#getNodeId_NameSpace()
+ * @model dataType="org.eclipse.uml2.types.String" ordered="false"
+ * @generated
+ */
+ String getNameSpace();
+
+ /**
+ * Sets the value of the '{@link org.eclipse.papyrus.aas.NodeId#getNameSpace <em>Name Space</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @param value the new value of the '<em>Name Space</em>' attribute.
+ * @see #getNameSpace()
+ * @generated
+ */
+ void setNameSpace(String value);
+
+ /**
+ * Returns the value of the '<em><b>Name Space Index</b></em>' attribute.
+ * <!-- begin-user-doc -->
+ * <p>
+ * If the meaning of the '<em>Name Space Index</em>' attribute isn't clear,
+ * there really should be more of a description here...
+ * </p>
+ * <!-- end-user-doc -->
+ * @return the value of the '<em>Name Space Index</em>' attribute.
+ * @see #setNameSpaceIndex(int)
+ * @see org.eclipse.papyrus.aas.AASPackage#getNodeId_NameSpaceIndex()
+ * @model dataType="org.eclipse.uml2.types.Integer" ordered="false"
+ * @generated
+ */
+ int getNameSpaceIndex();
+
+ /**
+ * Sets the value of the '{@link org.eclipse.papyrus.aas.NodeId#getNameSpaceIndex <em>Name Space Index</em>}' attribute.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @param value the new value of the '<em>Name Space Index</em>' attribute.
+ * @see #getNameSpaceIndex()
+ * @generated
+ */
+ void setNameSpaceIndex(int value);
/**
* Returns the value of the '<em><b>Identifier</b></em>' attribute.
@@ -71,7 +125,7 @@ public interface NodeId extends EObject {
* @return the value of the '<em>Identifier</em>' attribute.
* @see #setIdentifier(String)
* @see org.eclipse.papyrus.aas.AASPackage#getNodeId_Identifier()
- * @model dataType="org.eclipse.uml2.types.String" required="true" ordered="false"
+ * @model dataType="org.eclipse.uml2.types.String" ordered="false"
* @generated
*/
String getIdentifier();
@@ -99,7 +153,7 @@ public interface NodeId extends EObject {
* @see org.eclipse.papyrus.aas.IdType
* @see #setIdType(IdType)
* @see org.eclipse.papyrus.aas.AASPackage#getNodeId_IdType()
- * @model required="true" ordered="false"
+ * @model ordered="false"
* @generated
*/
IdType getIdType();
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
public interface NodeId extends EObject {
/**
- * Returns the value of the '<em><b>Namespace</b></em>' attribute.
+ * Returns the value of the '<em><b>Topic</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Namespace</em>' attribute isn't clear,
+ * If the meaning of the '<em>Topic</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Namespace</em>' attribute.
- * @see #setNamespace(int)
- * @see org.eclipse.papyrus.aas.AASPackage#getNodeId_Namespace()
- * @model dataType="org.eclipse.uml2.types.Integer" required="true" ordered="false"
+ * @return the value of the '<em>Topic</em>' attribute.
+ * @see #setTopic(String)
+ * @see org.eclipse.papyrus.aas.AASPackage#getNodeId_Topic()
+ * @model dataType="org.eclipse.uml2.types.String" ordered="false"
* @generated
*/
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
/**
- * Sets the value of the '{@link org.eclipse.papyrus.aas.NodeId#getNamespace <em>Namespace</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.papyrus.aas.NodeId#getTopic <em>Topic</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -35,30 +37,82 @@ import org.eclipse.emf.ecore.EObject;
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Namespace</em>' attribute.
- * @see #getNamespace()
+ * @param value the new value of the '<em>Topic</em>' attribute.
+ * @see #getTopic()
* @generated
*/